/**
 * dessine un rectangle 
 * 
 * @param {CanvasRenderingContext2D} ctxt le contexte graphique du canvas
 * @param {number} x abscisse du coin supérieur gauche du rectangle
 * @param {number} y ordonnée du coin supérieur gauche du rectangle
 * @param {number} l longueur du rectangle
 * @param {number} h hauteur du rectangle
 * @param {string} couleurTrait la couleur du contour du rectangle
 * @param {string} couleurRemplissage la couleur de remplissage du rectangle
 */
function rectangle(ctxt, x, y, l, h, couleurTrait, couleurRemplissage) {
    ctxt.lineWidth = 3;
    ctxt.strokeStyle = couleurTrait;
    ctxt.fillStyle = couleurRemplissage;
    ctxt.fillRect(x, y, l, h);
    ctxt.strokeRect(x, y, l, h);
}

/**
 * dessine un escalier droit
 * @param {Canvas} canvas le canvas dans lequel l'escalier est dessiné
 * @param {number} nbMarches nombre de marches
 * @param {number} hauteur d'une marche (en pixels)
 * @param {string} couleurTrait la couleur du contour du rectangle
 * @param {string} couleurRemplissage la couleur de remplissage du rectangle
 */
function dessinerEscalier(canvas, nbMarches, hauteur, couleurTrait, couleurRemplissage) {
    const graphicContext = canvas.getContext("2d");
    const x = 0;
    let y = 0;
    let largeur = hauteur;
    for (let i = 1; i <= nbMarches; i++) {
        rectangle(graphicContext, x, y, largeur, hauteur, couleurTrait, couleurRemplissage);
        y = y + hauteur;
        largeur = largeur + hauteur;
    }
}

/**
 * dessine un escalier pyramidal
 * @param {Canvas} canvas le canvas dans lequel l'escalier est dessiné
 * @param {number} nbMarches nombre de marches
 * @param {number} hauteur d'une marche (en pixels)
 * @param {string} couleurTrait la couleur du contour d'une marche
 * @param {string} couleurRemplissage la couleur de remplissage d'une marche
 */
function dessinerPyramide(canvas, nbMarches, hauteur, couleurTrait, couleurRemplissage) {

    const graphicContext = canvas.getContext("2d");
    let x = canvas.width / 2 - hauteur;
    let y = 0;
    let largeur = 2 * hauteur;
    for (let i = 1; i <= nbMarches; i++) {
        rectangle(graphicContext, x, y, largeur, hauteur, couleurTrait, couleurRemplissage);
        y = y + hauteur;
        x = x - hauteur;
        largeur = largeur + 2 * hauteur;
    }
}

/**
 * efface le canvas
 * 
 * @param {Canvas} canvas le canvas à effacer
 */
function effacer(canvas) {
    const graphicContext = canvas.getContext("2d");
    graphicContext.clearRect(0, 0, canvas.width, canvas.height);
}

/**
 * fonction appelée un fois la page chargée. Associe les gestionnaires d'événements
 * aux boutons dessiner et effacer
 */
function init() {

    const canvas = document.getElementById("myCanvas");

    // dessine un escalier initial de 20 marches de hauteur 20
    dessinerEscalier(canvas, 20, 20, 'red', 'yellow');

    // associe une fonction de gestion à l'événement onclick du bouton 'effacer
    document.getElementById("effacer").addEventListener('click', () => effacer(canvas));
    // il existe d'autres manières d'écrire le code ci-dessus: 
    // 1) en utilisant une fonction anonyme plutôt qu'une fonction flêchée
    //
    //    document.getElementById("effacer").addEventListener('click', function() { effacer(canvas); });
    //
    // 2) passant directement par l'attribut onclick de l'élément bouton
    //
    //    document.getElementById("effacer").onclick = function () {
    //          effacer(canvas);
    //    };
    //
    //    la aussi on peut utiliser un expression de fonction flêchée
    //  
    //    document.getElementById("effacer").onclick = () => effacer(canvas);


    // associe une fonction de gestion à l'événement onclick du bouton 'dessiner'
    document.getElementById("dessiner").addEventListener('click',
            function () {
                const nb = parseInt(document.getElementById("nbreMarches").value);
                const hauteur = parseInt(document.getElementById("hauteurMarche").value);
                const strokeColor = document.getElementById("strokeColor").value;
                const fillColor = document.getElementById("fillColor").value;
                const escalier = document.getElementById("escalier").checked;
                effacer(canvas);
                if (escalier) {
                    dessinerEscalier(canvas, nb, hauteur, strokeColor, fillColor);
                } else {
                    dessinerPyramide(canvas, nb, hauteur, strokeColor, fillColor);
                }
            }
    );
}

// quand la page a été chargée et le DOM entièrement créé un événement onload est envoyé,
// la méthode init() est exécutée lorsque cet événement est déclanché
window.onload = init();


